#!/bin/bash

# first arg = number of threads
$i = $1

SCRIPT_DIR=$( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd )
LOG_FILE="$SCRIPT_DIR/../julia.log"

cd $SCRIPT_DIR/..

echo "Writing system info..."

printf "Current git commit hash: " > $LOG_FILE
git rev-parse HEAD >> $LOG_FILE
git status >> $LOG_FILE

# collect some information of the used node and system
uname -a > results/system.txt
julia --version > results/julia.txt
lscpu > results/cpu.txt
nvidia-smi > results/cuda_gpu.txt
lsblk > results/storage.txt
lspci > results/pci.txt

echo "Initiating julia..."
julia --project=./ -e 'using Pkg; Pkg.instantiate(); Pkg.add(url="https://github.com/QEDjl-project/QEDprocesses.jl/")' >> $LOG_FILE 2>&1 || exit 1    # need current dev version of QEDprocesses
julia -e 'using Pkg; Pkg.add("CSV"); Pkg.add("DataFrames"); Pkg.add("LIKWID"); Pkg.add("CUDA"); Pkg.add("Random")' >> $LOG_FILE 2>&1 || exit 1        # add requirements for the bench script

echo "Benchmarking..."
echo "$i Threads"
julia --project --threads=$i examples/qed_bench.jl >> $LOG_FILE 2>&1 || echo "-- Something went wrong, check logs --"

echo "Benchmarking Tape variant..."
echo "$i Threads"
julia --project --threads=$i examples/qed_bench_tape.jl >> $LOG_FILE 2>&1 || echo "-- Something went wrong, check logs --"
